Documentation
¶
Index ¶
- func DownloadImage(ctx context.Context, filePath string, ipfsURL string, outCid *string) error
- func IsIpfsPullRef(netRef string) bool
- func Pull(ctx context.Context, imgCache *cache.Handle, pullFrom string, tmpDir string) (imagePath string, err error)
- func PullToFile(ctx context.Context, imgCache *cache.Handle, pullTo, pullFrom string, ...) (imagePath string, err error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DownloadImage ¶
DownloadImage will retrieve an image from an ipfs URI, saving it into the specified file
func IsIpfsPullRef ¶
IsIpfsPullRef returns true if the provided string is a valid url reference for a pull operation.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.