Documentation
¶
Overview ¶
Package syfs provides functions to access apptainer's file system layout.
Index ¶
Constants ¶
const ( RemoteConfFile = "remote.yaml" RemoteCache = "remote-cache" DockerConfFile = "docker-config.json" )
Configuration files/directories.
Variables ¶
This section is empty.
Functions ¶
func ConfigDir ¶
func ConfigDir() string
ConfigDir returns the directory where the apptainer user configuration and data is located.
func ConfigDirForUsername ¶
ConfigDirForUsername returns the directory where the apptainer configuration and data for the specified username is located.
func DockerConf ¶
func DockerConf() string
func LegacyConfigDir ¶ added in v1.0.0
func LegacyConfigDir() string
LegacyConfigDir returns where singularity stores user configuration. NOTE: this location should only be used for migration/compatibility and never written to by apptainer.
func LegacyDockerConf ¶ added in v1.0.0
func LegacyDockerConf() string
LegacyDockerConf reutrns where singularity stores user oci registry configuration. NOTE: this location should only be used for migration/compatibility and never written to by apptainer.
func LegacyRemoteConf ¶ added in v1.0.0
func LegacyRemoteConf() string
LegacyRemoteConf returns where singularity stores user remote configuration. NOTE: this location should only be used for migration/compatibility and never written to by apptainer.
func RemoteCacheDir ¶
func RemoteCacheDir() string
func RemoteConf ¶
func RemoteConf() string
Types ¶
This section is empty.